package com.ruoyi.web.controller.learn;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.learn.domain.LearnPlanStudy;
import com.ruoyi.learn.service.ILearnPlanStudyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 学生计划执行情况Controller
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
@RestController
@RequestMapping("/learn/learnPlanStudy")
public class LearnPlanStudyController extends BaseController
{
    @Autowired
    private ILearnPlanStudyService learnPlanStudyService;

    /**
     * 查询学生计划执行情况列表
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlanStudy:list')")
    @GetMapping("/list")
    public TableDataInfo list(LearnPlanStudy learnPlanStudy)
    {
        startPage();
        List<LearnPlanStudy> list = learnPlanStudyService.selectLearnPlanStudyList(learnPlanStudy);
        return getDataTable(list);
    }

    /**
     * 导出学生计划执行情况列表
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlanStudy:export')")
    @Log(title = "学生计划执行情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LearnPlanStudy learnPlanStudy)
    {
        List<LearnPlanStudy> list = learnPlanStudyService.selectLearnPlanStudyList(learnPlanStudy);
        ExcelUtil<LearnPlanStudy> util = new ExcelUtil<LearnPlanStudy>(LearnPlanStudy.class);
        util.exportExcel(response, list, "学生计划执行情况数据");
    }

    /**
     * 获取学生计划执行情况详细信息
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlanStudy:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(learnPlanStudyService.selectLearnPlanStudyById(id));
    }

    /**
     * 新增学生计划执行情况
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlanStudy:add')")
    @Log(title = "学生计划执行情况", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LearnPlanStudy learnPlanStudy)
    {
        return toAjax(learnPlanStudyService.insertLearnPlanStudy(learnPlanStudy));
    }

    /**
     * 修改学生计划执行情况
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlanStudy:edit')")
    @Log(title = "学生计划执行情况", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LearnPlanStudy learnPlanStudy)
    {
        return toAjax(learnPlanStudyService.updateLearnPlanStudy(learnPlanStudy));
    }

    /**
     * 删除学生计划执行情况
     */
    @PreAuthorize("@ss.hasPermi('learn:learnPlanStudy:remove')")
    @Log(title = "学生计划执行情况", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(learnPlanStudyService.deleteLearnPlanStudyByIds(ids));
    }
}
